#!/bin/bash
cd "$(dirname "${BASH_SOURCE[0]}")"

# Check AVX2 support
cputype=generic
if sysctl hw.optional | grep -Fq 'avx2_0: 1'; then
	echo "Detected AVX2 support"
	cputype=avx2
fi

function install_vlc()
{
	echo "************************"
	echo "Installing VLC plugin..."
	echo "************************"
	
	# Check arch
	arch=`uname -m`
	if [[ $arch == x86_64 ]] ; then
		arch=x64
	else
		echo >&2 "Unsupported architecture: '$arch'. Skipping."
		return 1
	fi
	
	# Check VLC
	vlcdir="/Applications/VLC.app/Contents/MacOS"
	vlcbin="$vlcdir/VLC"
	if [ ! -f "$vlcbin" ] ; then
		echo >&2 "VLC doesn't seem to be installed. Skipping."
		return 1
	fi
	
	# Try to determine VLC version
	regex="([[:digit:]])+\.([[:digit:]])+\.([[:digit:]])+"
	vlcout=$($vlcbin --version 2>/dev/null)
	[[ $vlcout =~ $regex ]]
	maj="${BASH_REMATCH[1]}"
	min="${BASH_REMATCH[2]}"
	rev="${BASH_REMATCH[3]}"
	echo "Detected VLC: $vlcbin ($arch) $maj.$min.$rev"
	
	# Check if we have a matching plugin
	plugin="VLC/$arch/$cputype/$maj.$min.x/libmagicyuv_plugin.dylib"
	if [ ! -f "$plugin" ] ; then
		echo >&2 "There is no MagicYUV codec available for this VLC version. Skipping."
		return 1
	fi
	
	# Check VLC plugins dir
	vlccodecs="$vlcdir/plugins"
	if [ ! -d "$vlccodecs" ]; then
		echo >&2 "Assumed VLC codecs dir '$vlccodecs' doesn't exist. Skipping."
		return 1
	fi
	
	# Install
	echo "Installing '$plugin' to '$vlccodecs'"
	cp -v $plugin $vlccodecs
	if [ $? -ne 0 ] ; then
		echo >&2 "VLC plugin installation failed, trying as admin (sudo)..."
		sudo cp -v $plugin $vlccodecs || { echo >&2 "VLC plugin installation failed."; return 1; }
	fi
	echo "Done."
}

function install_qt()
{
	echo "*********************************"
	echo "Installing QuickTime component..."
	echo "*********************************"
	qtcomp=QuickTime/$cputype/MagicYUV.component
	echo "Installing '$qtcomp' to '/Library/QuickTime' using sudo"
	sudo -p "Enter your password (or press Control-C to skip and install locally for current user only): " cp -R $qtcomp /Library/QuickTime
	if [ $? -ne 0 ] ; then
		echo >&2 "Global QuickTime component installation failed."
		read -r -p "Install only for current user? [y/N] " response
		if [[ $response =~ ^[yY]$ ]] ; then
			echo "Installing '$qtcomp' to '~/Library/QuickTime'"
			cp -R $qtcomp ~/Library/QuickTime
			echo "Done."
			return 0
		fi
		return 1
	fi
	echo "Done."
}

install_vlc
echo ""
install_qt
echo ""
